Sampling and Text Processing from Online Libraries (decompser.py)
=================================================================

   |

With the decomposer module, one can sample random documents (books, etc.) from Project Gutenberg and Archive.org and rearrange the texts using Markov chain algorithms, cut-up, or by swapping instances of a part of speech between two texts.

.. automodule:: generativepoetry.decomposer
   :members:

   |

The ParsedText class has several methods for random sampling.

.. autoclass:: generativepoetry.decomposer.ParsedText
   :members:
